package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseDevicePurchase;
import com.hw.dms.service.IDmsBaseDevicePurchaseService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 设备采购信息Controller
 * 
 * @author xins
 * @date 2024-01-09
 */
@RestController
@RequestMapping("/purchase")
public class DmsBaseDevicePurchaseController extends BaseController
{
    @Autowired
    private IDmsBaseDevicePurchaseService dmsBaseDevicePurchaseService;

    /**
     * 查询设备采购信息列表
     */
    @RequiresPermissions("dms:purchase:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseDevicePurchase dmsBaseDevicePurchase)
    {
        startPage();
        List<DmsBaseDevicePurchase> list = dmsBaseDevicePurchaseService.selectDmsBaseDevicePurchaseList(dmsBaseDevicePurchase);
        return getDataTable(list);
    }

    /**
     * 导出设备采购信息列表
     */
    @RequiresPermissions("dms:purchase:export")
    @Log(title = "设备采购信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseDevicePurchase dmsBaseDevicePurchase)
    {
        List<DmsBaseDevicePurchase> list = dmsBaseDevicePurchaseService.selectDmsBaseDevicePurchaseList(dmsBaseDevicePurchase);
        ExcelUtil<DmsBaseDevicePurchase> util = new ExcelUtil<DmsBaseDevicePurchase>(DmsBaseDevicePurchase.class);
        util.exportExcel(response, list, "设备采购信息数据");
    }

    /**
     * 获取设备采购信息详细信息
     */
    @RequiresPermissions("dms:purchase:query")
    @GetMapping(value = "/{devicePurchaseId}")
    public AjaxResult getInfo(@PathVariable("devicePurchaseId") Long devicePurchaseId)
    {
        return success(dmsBaseDevicePurchaseService.selectDmsBaseDevicePurchaseByDevicePurchaseId(devicePurchaseId));
    }

    /**
     * 新增设备采购信息
     */
    @RequiresPermissions("dms:purchase:add")
    @Log(title = "设备采购信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseDevicePurchase dmsBaseDevicePurchase)
    {
        return toAjax(dmsBaseDevicePurchaseService.insertDmsBaseDevicePurchase(dmsBaseDevicePurchase));
    }

    /**
     * 修改设备采购信息
     */
    @RequiresPermissions("dms:purchase:edit")
    @Log(title = "设备采购信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseDevicePurchase dmsBaseDevicePurchase)
    {
        return toAjax(dmsBaseDevicePurchaseService.updateDmsBaseDevicePurchase(dmsBaseDevicePurchase));
    }

    /**
     * 删除设备采购信息
     */
    @RequiresPermissions("dms:purchase:remove")
    @Log(title = "设备采购信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{devicePurchaseIds}")
    public AjaxResult remove(@PathVariable Long[] devicePurchaseIds)
    {
        return toAjax(dmsBaseDevicePurchaseService.deleteDmsBaseDevicePurchaseByDevicePurchaseIds(devicePurchaseIds));
    }
}
